@@ -1,7 +1,7 @@
 package WWW::PAUSE::Simple;
 
 our $DATE = '2018-04-26'; # DATE
-our $VERSION = '0.440'; # VERSION
+our $VERSION = '0.441'; # VERSION
 
 use 5.010001;
 use strict;
@@ -645,11 +645,23 @@ sub _delete_or_undelete_or_reindex_files {
         log_info("%s %s ...", $which, \@files);
     }
 
+    my $action;
+    if ($which eq 'delete') {
+        $action = 'delete_files';
+    } elsif ($which eq 'undelete') {
+        $action = 'delete_files';
+    } elsif ($which eq 'reindex') {
+        $action = 'reindex';
+    } else {
+        die "BUG: undefined action";
+    }
+
     my $httpres = _request(
         note => "$which files",
         %args,
         post_data => [
             [
+                ACTION => $action,
                 HIDDENNAME                => $args{username},
                 ($which eq 'delete'   ? (SUBMIT_pause99_delete_files_delete   => "Delete"  ) : ()),
                 ($which eq 'undelete' ? (SUBMIT_pause99_delete_files_undelete => "Undelete") : ()),
@@ -855,7 +867,7 @@ WWW::PAUSE::Simple - An API for PAUSE
 
 =head1 VERSION
 
-This document describes version 0.440 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2018-04-26.
+This document describes version 0.441 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2018-04-26.
 
 =head1 SYNOPSIS
 
